
__version__ = "7.00"
__author__ = "Alex Al-Saffar"
__date__ = "2022-05-05"
docs = r"https://crocodile.readthedocs.io/en/latest/"
git = r"https://github.com/thisismygitrepo/crocodile"
release_notes = """
LTS Stable Release.
"""
